#!/usr/bin/env python
#
# Child EnVars post-processing script for NZBGet
#
# Copyright (C) 2013 Patrick Dell'Era <patrick.dellera@gmail.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#


##############################################################################
### NZBGET POST-PROCESSING SCRIPT                                          ###

# Set and get environment variables for child process
#
# This script enables a child process to modify environment variables
# and allow a parent process to read them. This allows post-process
# scripts to further process files after they have been sorted
# and renamed by sorting.
#
# The new envars are stored and retrieved from a text file
# that is maintained in the same directory as the logging
# file to assure read and write permissions are in place.
#
# NOTE: This script requires Python to be installed on your system.

### NZBGET POST-PROCESSING SCRIPT                                          ###
##############################################################################


import os
import sys

# Exit codes used by NZBGet
POSTPROCESS_SUCCESS=93
POSTPROCESS_NONE=95
POSTPROCESS_ERROR=94

# Check if the script is called from nzbget 11.0 or later
if not 'NZBOP_SCRIPTDIR' in os.environ:
	print('*** NZBGet post-processing script ***')
	print('This script is supposed to be called from nzbget (11.0 or later).')
	sys.exit(POSTPROCESS_ERROR)

# define a text file to retrieve child environment variables
def Path():
	vars_path = ""
	try:
		vars_path = os.path.split(os.environ['NZBOP_LOGFILE'])[0]
		vars_path = os.path.join(vars_path, 'childenvars')
	except Exception as e:
		print('[ERROR] Failed: Deriving childenvars  file name.')
		print('[ERROR] %s' % e)

	#print("vars_path=\"%s\"" % vars_path)
	return vars_path

def Read():
	childenvars = {}
	vars_path = ""
	try:
		vars_path = Path()
		if len(vars_path) > 0 and os.path.exists(vars_path):
			with open(vars_path) as f:
				line = f.readline()
				while line:
					line = line.strip()
					if len(line) > 0:
						varKey, varValue = line.split('=')
						if len(varKey) > 0:
							childenvars[varKey] = varValue
					line = f.readline()
	except Exception as e:
		print('[ERROR] Failed: Reading childenvars from %s.' % vars_path)
		print('[ERROR] %s' % e)

	return childenvars

def Write(childenvars):
	vars_path = ""
	try:
		vars_path = Path()
		if len(vars_path) > 0:
			with open(vars_path, 'w') as f:
				for k, v in childenvars.iteritems():
					f.write('%s=%s\n' % (k,v))
	except Exception as e:
		print('[ERROR] Failed: Writing childenvars to %s.' % vars_path)
		print('[ERROR] %s' % e)

def Put( varKey, varValue):
	childenvars = {}
	try:
		if len(varKey) > 0:
			childenvars = Read()
			if len(varValue) > 0:
				childenvars[varKey] = varValue
			else:
				if varKey in childenvars:
					del childenvars[varKey]
			Write(childenvars)
	except Exception as e:
		print('[ERROR] Failed: Putting child environmental variable')
		print('[ERROR] %s' % e)

def Get(varKey):
	varValue = ""
	try:
		childenvars = Read()
		if childenvars is not None:
			varValue=childenvars.get(varKey, '')
	except Exception as e:
		print('[ERROR] Failed: Getting child environmental variable')
		print('[ERROR] %s' % e)
	return varValue

def Clear():
	vars_path = ""
	try:
		vars_path = Path()
		if len(vars_path) > 0 and os.path.exists(vars_path):
			#print "Yes, actually removing."
			os.remove(vars_path)
	except Exception as e:
		print('[ERROR] Failed: Deleting file %s.' % vars_path)
		print('[ERROR] %s' % e)

if __name__ == '__main__':
	if False:
		print "Clearing envars."
		Clear()
		print( "putting foo=bar")
		Put('foo','bar')
		print("retrieving foo")
		print("foo=\"%s\"" % Get('foo'))
		print( "putting foo=beyond all recognition")
		Put('foo', 'beyond all recognition')
		print("retrieving foo")
		print("foo=\"%s\"" % Get('foo'))
		print("retrieving DoesNotExist")
		print("DoesNotExist=\"%s\"" % Get('DoesNotExist'))
		print("Removing foo.")
		Put('foo', '')
		envars = Read()
		print("Envars:")
		print envars
		print "...."
		path = 'Z:\Media/Movies\Shadow Dancer (2012)\Shadow Dancer (2012)'
		Put('NZBPP_DIRECTORY', path)
		Put('NZBPP_NZBFILENAME', path + ".nzb")
		Put('NZBPP_NZBNAME', os.path.split(path)[1])
		print("NZBPP_DIRECTORY=\"%s\"" % Get('NZBPP_DIRECTORY'))
		print("NZBPP_NZBFILENAME=\"%s\"" % Get('NZBPP_NZBFILENAME'))
		print("NZBPP_NZBNAME=\"%s\"" % Get('NZBPP_NZBNAME'))
